<template>
  <NutForm
    :model-value="form"
    ref="formRef"
    :rules="rules"
    label-position="top"
    class="order-bill-recharge phone chunk-form"
  >
    <NutFormItem label="公司名称" class="bole-form-item" prop="companyName">
      <NutInput
        v-model.trim="form.companyName"
        class="bole-input-text"
        placeholder="请填写您的公司名称"
        type="text"
      />
    </NutFormItem>
    <NutFormItem label="姓名" class="bole-form-item" prop="name" required>
      <NutInput
        v-model.trim="form.name"
        class="bole-input-text"
        placeholder="请填写您的姓名"
        type="text"
      />
    </NutFormItem>
    <NutFormItem label="联系方式" class="bole-form-item" prop="phoneNumber" required>
      <NutInput
        v-model.trim="form.phoneNumber"
        class="bole-input-text"
        placeholder="请填写您的联系方式"
        type="text"
      />
    </NutFormItem>
    <NutFormItem label="意向代理类型 " class="bole-form-item" prop="type" required>
      <ChooseInputWithPicker
        v-model="form.type"
        placeholder="请选择您想申请的代理类型"
        :value-enum="[]"
        enum-label-key="gasOrgName"
        enum-value-key="gasOrgCode"
      />
    </NutFormItem>
    <NutFormItem label="客户资源" class="bole-form-item" prop="refundApplyRemark" required>
      <NutTextarea
        placeholder="请填写您拥有的客户资源"
        placeholderClass="bole-input-text-placeholder"
        autoSize
        class="bole-input-textarea"
        v-model="form.refundApplyRemark"
        :max-length="200"
        limit-show
      >
      </NutTextarea>
    </NutFormItem>
  </NutForm>
</template>

<script setup lang="ts">
import {
  Form as NutForm,
  FormItem as NutFormItem,
  Input as NutInput,
  Textarea as NutTextarea,
} from '@nutui/nutui-taro';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { reactive, ref, computed } from 'vue';
import { useLifeRechargeContext } from '@life-payment/core-vue';
import { FormValidator } from '../../utils';
import ChooseInputWithPicker from '../../components/Input/ChooseInputWithPicker.vue';

defineOptions({
  name: 'ApplyAgentView',
});

const emit = defineEmits<{
  (e: 'submit'): void;
}>();

const form = reactive({
  companyName: '',
  name: '',
  phoneNumber: '',
  type: '',
  refundApplyRemark: '',
});

const rules = reactive<FormRules>({
  name: [{ required: true, message: '请填写您的姓名' }],
  phoneNumber: [
    { required: true, message: '请填写您的联系方式' },
    { validator: FormValidator.validatorPhoneNumber, message: '请输入正确的手机号' },
  ],
  refundApplyRemark: [{ required: true, message: '请输入退款原因' }],
});

const { blLifeRecharge } = useLifeRechargeContext();

const formRef = ref<any>(null);

function handleSubmit() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      refundUserLifePayOrder();
    }
  });
}

async function refundUserLifePayOrder() {
  try {
    let params = {
      userId: blLifeRecharge.accountModel.userId,
      refundApplyRemark: form.refundApplyRemark,
    };
    let res = await blLifeRecharge.services.refundUserLifePayOrder(params);
    emit('submit');
  } catch (error) {}
}

defineExpose({
  handleSubmit,
});
</script>
